@@ -1,10 +1,9 @@
 from django.core.checks.security.base import SECRET_KEY_INSECURE_PREFIX
 from django.core.management import BaseCommand
-from django.core.management.templates import TemplateCommand
 from django.core.management.utils import get_random_secret_key
 
 
-class Command(TemplateCommand):
+class Command(BaseCommand):
     help = (
         "Creates a Django project directory structure for the given project "
         "name in the current directory or optionally in the given directory."
